@@ -219,6 +219,8 @@ extern char *plpgsql_check_get_src(HeapTuple procTuple);
 extern Oid plpgsql_check_pragma_func_oid(void);
 extern bool plpgsql_check_is_plpgsql_function(Oid foid);
 extern Oid plpgsql_check_get_op_namespace(Oid opno);
+extern char *get_extension_version(Oid ext_oid);
+
 
 /*
  * functions from tablefunc.c
@@ -322,6 +324,7 @@ extern PLpgSQL_row * plpgsql_check_CallExprGetRowTarget(PLpgSQL_checkstate *csta
 extern Oid plpgsql_check_parse_name_or_signature(char *name_or_signature);
 extern bool plpgsql_check_pragma_type(PLpgSQL_checkstate *cstate, const char *str, PLpgSQL_nsitem *ns, int lineno);
 extern bool plpgsql_check_pragma_table(PLpgSQL_checkstate *cstate, const char *str, int lineno);
+extern bool plpgsql_check_pragma_sequence(PLpgSQL_checkstate *cstate, const char *str, int lineno);
 extern void plpgsql_check_search_comment_options(plpgsql_check_info *cinfo);
 extern char *plpgsql_check_process_echo_string(char *str, plpgsql_check_info *cinfo);
 
@@ -411,6 +414,8 @@ extern shmem_startup_hook_type prev_shmem_startup_hook;
 extern PLpgSQL_plugin **plpgsql_check_plugin_var_ptr;
 extern PLpgSQL_plugin *prev_plpgsql_plugin;
 
+extern void plpgsql_check_check_ext_version(Oid fn_oid);
+
 #if PG_VERSION_NUM > 110005
 
 #define PLPGSQL_BUILD_DATATYPE_4		1
